BrowserProcessKind class

Indicates the process type used in the BrowserProcessInfo interface.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override
operator |(BrowserProcessKind value) → BrowserProcessKind

Static Properties

BROWSER → BrowserProcessKind
Indicates the browser process kind.
final
GPU → BrowserProcessKind
Indicates the GPU process kind.
final
PPAPI_BROKER → BrowserProcessKind
Indicates the PPAPI plugin broker process kind.
final
PPAPI_PLUGIN → BrowserProcessKind
Indicates the PPAPI plugin process kind.
final
RENDERER → BrowserProcessKind
Indicates the render process kind.
final
SANDBOX_HELPER → BrowserProcessKind
Indicates the sandbox helper process kind.
final
UTILITY → BrowserProcessKind
Indicates the utility process kind.
final
values → Set<BrowserProcessKind>
Set of all values of BrowserProcessKind.
final

Static Methods

asNameMap() → Map<String, BrowserProcessKind>
Creates a map from the names of BrowserProcessKind values to the values.
byName(String? name) → BrowserProcessKind?
Gets a possible BrowserProcessKind instance value with name name.
fromNativeValue(int? value) → BrowserProcessKind?
Gets a possible BrowserProcessKind instance from a native value.
fromValue(int? value) → BrowserProcessKind?
Gets a possible BrowserProcessKind instance from int value.