CacheModel class

Cache model for WebKitWebContext.

Determines how caching is handled for web content.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

DOCUMENT_BROWSER → CacheModel
A cache model optimized for viewing a series of local files, such as ebooks, without browsing a variety of online content.
final
DOCUMENT_VIEWER → CacheModel
Disable the cache completely, which is useful for ephemeral applications or applications without a persistent data storage. Using this cache model can have important security implications for your application. All pages are loaded from the server without caching.
final
values → Set<CacheModel>
Set of all values of CacheModel.
final
WEB_BROWSER → CacheModel
Improves document load speed substantially by caching a very large number of resources and previously visited content. This mode is optimal for web browser applications.
final

Static Methods

asNameMap() → Map<String, CacheModel>
Creates a map from the names of CacheModel values to the values.
byName(String? name) → CacheModel?
Gets a possible CacheModel instance value with name name.
fromNativeValue(int? value) → CacheModel?
Gets a possible CacheModel instance from a native value.
fromValue(int? value) → CacheModel?
Gets a possible CacheModel instance from int value.