DownloadStartResponseAction class

Class representing the action of a DownloadStartResponse.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

CANCEL → DownloadStartResponseAction
Cancel the download.
final
values → Set<DownloadStartResponseAction>
Set of all values of DownloadStartResponseAction.
final

Static Methods

asNameMap() → Map<String, DownloadStartResponseAction>
Creates a map from the names of DownloadStartResponseAction values to the values.
byName(String? name) → DownloadStartResponseAction?
Gets a possible DownloadStartResponseAction instance value with name name.
fromNativeValue(int? value) → DownloadStartResponseAction?
Gets a possible DownloadStartResponseAction instance from a native value.
fromValue(int? value) → DownloadStartResponseAction?
Gets a possible DownloadStartResponseAction instance from int value.