HttpAuthResponseAction class

Class used by HttpAuthResponse class.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

CANCEL → HttpAuthResponseAction
Instructs the WebView to cancel the authentication request.
final
PROCEED → HttpAuthResponseAction
Instructs the WebView to proceed with the authentication with the given credentials.
final
USE_SAVED_HTTP_AUTH_CREDENTIALS → HttpAuthResponseAction
Uses the credentials stored for the current host.
final
values → Set<HttpAuthResponseAction>
Set of all values of HttpAuthResponseAction.
final

Static Methods

asNameMap() → Map<String, HttpAuthResponseAction>
Creates a map from the names of HttpAuthResponseAction values to the values.
byName(String? name) → HttpAuthResponseAction?
Gets a possible HttpAuthResponseAction instance value with name name.
fromNativeValue(int? value) → HttpAuthResponseAction?
Gets a possible HttpAuthResponseAction instance from a native value.
fromValue(int? value) → HttpAuthResponseAction?
Gets a possible HttpAuthResponseAction instance from int value.