IOSWKSelectionGranularity class

An iOS-specific class used to set the level of granularity with which the user can interactively select content in the web view. Use SelectionGranularity instead.

Annotations

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → int?
Gets int native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → int
Gets int value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<IOSWKSelectionGranularity>
Set of all values of IOSWKSelectionGranularity.
final

Static Methods

asNameMap() → Map<String, IOSWKSelectionGranularity>
Creates a map from the names of IOSWKSelectionGranularity values to the values.
byName(String? name) → IOSWKSelectionGranularity?
Gets a possible IOSWKSelectionGranularity instance value with name name.
fromNativeValue(int? value) → IOSWKSelectionGranularity?
Gets a possible IOSWKSelectionGranularity instance from a native value.
fromValue(int? value) → IOSWKSelectionGranularity?
Gets a possible IOSWKSelectionGranularity instance from int value.

Constants

CHARACTER → const IOSWKSelectionGranularity
Selection endpoints can be placed at any character boundary.
DYNAMIC → const IOSWKSelectionGranularity
Selection granularity varies automatically based on the selection.