InAppWebViewPlatform class abstract

Interface for a platform implementation of a WebView.

Inheritance
  • Object
  • PlatformInterface
  • InAppWebViewPlatform

Constructors

InAppWebViewPlatform()
Creates a new InAppWebViewPlatform.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createPlatformAssetsPathHandler(PlatformAssetsPathHandlerCreationParams params) → PlatformAssetsPathHandler
Creates a new PlatformAssetsPathHandler.
createPlatformAssetsPathHandlerStatic() → PlatformAssetsPathHandler
Creates a new empty PlatformAssetsPathHandler to access static methods.
createPlatformChromeSafariBrowser(PlatformChromeSafariBrowserCreationParams params) → PlatformChromeSafariBrowser
Creates a new PlatformChromeSafariBrowser.
createPlatformChromeSafariBrowserStatic() → PlatformChromeSafariBrowser
Creates a new empty PlatformChromeSafariBrowser to access static methods.
createPlatformCookieManager(PlatformCookieManagerCreationParams params) → PlatformCookieManager
Creates a new PlatformCookieManager.
createPlatformCookieManagerStatic() → PlatformCookieManager
Creates a new empty PlatformCookieManager to access static methods.
createPlatformCustomPathHandler(PlatformCustomPathHandlerCreationParams params) → PlatformCustomPathHandler
Creates a new PlatformCustomPathHandler.
createPlatformCustomPathHandlerStatic() → PlatformCustomPathHandler
Creates a new empty PlatformCustomPathHandler to access static methods.
createPlatformFindInteractionController(PlatformFindInteractionControllerCreationParams params) → PlatformFindInteractionController
Creates a new PlatformFindInteractionController.
createPlatformFindInteractionControllerStatic() → PlatformFindInteractionController
Creates a new empty PlatformFindInteractionController to access static methods.
createPlatformHeadlessInAppWebView(PlatformHeadlessInAppWebViewCreationParams params) → PlatformHeadlessInAppWebView
Creates a new PlatformHeadlessInAppWebView.
createPlatformHeadlessInAppWebViewStatic() → PlatformHeadlessInAppWebView
Creates a new empty PlatformHeadlessInAppWebView to access static methods.
createPlatformHttpAuthCredentialDatabase(PlatformHttpAuthCredentialDatabaseCreationParams params) → PlatformHttpAuthCredentialDatabase
Creates a new PlatformHttpAuthCredentialDatabase.
createPlatformHttpAuthCredentialDatabaseStatic() → PlatformHttpAuthCredentialDatabase
Creates a new empty PlatformHttpAuthCredentialDatabase to access static methods.
createPlatformInAppBrowser(PlatformInAppBrowserCreationParams params) → PlatformInAppBrowser
Creates a new PlatformInAppBrowser.
createPlatformInAppBrowserStatic() → PlatformInAppBrowser
Creates a new empty PlatformInAppBrowser to access static methods.
createPlatformInAppLocalhostServer(PlatformInAppLocalhostServerCreationParams params) → PlatformInAppLocalhostServer
Creates a new empty PlatformInAppLocalhostServer to access static methods.
createPlatformInAppLocalhostServerStatic() → PlatformInAppLocalhostServer
Creates a new empty PlatformInAppLocalhostServer to access static methods.
createPlatformInAppWebViewController(PlatformInAppWebViewControllerCreationParams params) → PlatformInAppWebViewController
Creates a new PlatformInAppWebViewController.
createPlatformInAppWebViewControllerStatic() → PlatformInAppWebViewController
Creates a new empty PlatformInAppWebViewController to access static methods.
createPlatformInAppWebViewWidget(PlatformInAppWebViewWidgetCreationParams params) → PlatformInAppWebViewWidget
Creates a new PlatformInAppWebViewWidget.
createPlatformInAppWebViewWidgetStatic() → PlatformInAppWebViewWidget
Creates a new empty PlatformInAppWebViewWidget to access static methods.
createPlatformInternalStoragePathHandler(PlatformInternalStoragePathHandlerCreationParams params) → PlatformInternalStoragePathHandler
Creates a new PlatformInternalStoragePathHandler.
createPlatformInternalStoragePathHandlerStatic() → PlatformInternalStoragePathHandler
Creates a new empty PlatformInternalStoragePathHandler to access static methods.
createPlatformJavaScriptReplyProxy(PlatformJavaScriptReplyProxyCreationParams params) → PlatformJavaScriptReplyProxy
Creates a new PlatformJavaScriptReplyProxy.
createPlatformLocalStorage(PlatformLocalStorageCreationParams params) → PlatformLocalStorage
Creates a new PlatformLocalStorage.
createPlatformLocalStorageStatic() → PlatformLocalStorage
Creates a new empty PlatformLocalStorage to access static methods.
createPlatformPrintJobController(PlatformPrintJobControllerCreationParams params) → PlatformPrintJobController
Creates a new PlatformPrintJobController.
createPlatformPrintJobControllerStatic() → PlatformPrintJobController
Creates a new empty PlatformPrintJobController to access static methods.
createPlatformProcessGlobalConfig(PlatformProcessGlobalConfigCreationParams params) → PlatformProcessGlobalConfig
Creates a new PlatformProcessGlobalConfig.
createPlatformProcessGlobalConfigStatic() → PlatformProcessGlobalConfig
Creates a new empty PlatformProcessGlobalConfig to access static methods.
createPlatformProxyController(PlatformProxyControllerCreationParams params) → PlatformProxyController
Creates a new PlatformProxyController.
createPlatformProxyControllerStatic() → PlatformProxyController
Creates a new empty PlatformProxyController to access static methods.
createPlatformPullToRefreshController(PlatformPullToRefreshControllerCreationParams params) → PlatformPullToRefreshController
Creates a new PlatformPullToRefreshController.
createPlatformPullToRefreshControllerStatic() → PlatformPullToRefreshController
Creates a new empty PlatformPullToRefreshController to access static methods.
createPlatformResourcesPathHandler(PlatformResourcesPathHandlerCreationParams params) → PlatformResourcesPathHandler
Creates a new PlatformResourcesPathHandler.
createPlatformResourcesPathHandlerStatic() → PlatformResourcesPathHandler
Creates a new empty PlatformResourcesPathHandler to access static methods.
createPlatformServiceWorkerController(PlatformServiceWorkerControllerCreationParams params) → PlatformServiceWorkerController
Creates a new PlatformServiceWorkerController.
createPlatformServiceWorkerControllerStatic() → PlatformServiceWorkerController
Creates a new empty PlatformServiceWorkerController to access static methods.
createPlatformSessionStorage(PlatformSessionStorageCreationParams params) → PlatformSessionStorage
Creates a new PlatformSessionStorage.
createPlatformSessionStorageStatic() → PlatformSessionStorage
Creates a new empty PlatformSessionStorage to access static methods.
createPlatformTracingController(PlatformTracingControllerCreationParams params) → PlatformTracingController
Creates a new PlatformTracingController.
createPlatformTracingControllerStatic() → PlatformTracingController
Creates a new empty PlatformTracingController to access static methods.
createPlatformWebAuthenticationSession(PlatformWebAuthenticationSessionCreationParams params) → PlatformWebAuthenticationSession
Creates a new PlatformWebAuthenticationSession.
createPlatformWebAuthenticationSessionStatic() → PlatformWebAuthenticationSession
Creates a new empty PlatformWebAuthenticationSession to access static methods.
createPlatformWebMessageChannel(PlatformWebMessageChannelCreationParams params) → PlatformWebMessageChannel
Creates a new PlatformWebMessageChannel.
createPlatformWebMessageChannelStatic() → PlatformWebMessageChannel
Creates a new empty PlatformWebMessageChannel to access static methods.
createPlatformWebMessageListener(PlatformWebMessageListenerCreationParams params) → PlatformWebMessageListener
Creates a new PlatformWebMessageListener.
createPlatformWebMessageListenerStatic() → PlatformWebMessageListener
Creates a new empty PlatformWebMessageListener to access static methods.
createPlatformWebMessagePort(PlatformWebMessagePortCreationParams params) → PlatformWebMessagePort
Creates a new PlatformWebMessagePort.
createPlatformWebNotificationController(PlatformWebNotificationControllerCreationParams params) → PlatformWebNotificationController
Creates a new PlatformWebNotificationController.
createPlatformWebNotificationControllerStatic() → PlatformWebNotificationController
Creates a new empty PlatformWebNotificationController to access static methods.
createPlatformWebStorage(PlatformWebStorageCreationParams params) → PlatformWebStorage
Creates a new PlatformWebStorage.
createPlatformWebStorageManager(PlatformWebStorageManagerCreationParams params) → PlatformWebStorageManager
Creates a new PlatformWebStorageManager.
createPlatformWebStorageManagerStatic() → PlatformWebStorageManager
Creates a new empty PlatformWebStorageManager to access static methods.
createPlatformWebStorageStatic() → PlatformWebStorage
Creates a new empty PlatformWebStorage to access static methods.
createPlatformWebViewEnvironment(PlatformWebViewEnvironmentCreationParams params) → PlatformWebViewEnvironment
Creates a new PlatformWebViewEnvironment.
createPlatformWebViewEnvironmentStatic() → PlatformWebViewEnvironment
Creates a new empty PlatformWebViewEnvironment to access static methods.
createPlatformWebViewFeature(PlatformWebViewFeatureCreationParams params) → PlatformWebViewFeature
Creates a new PlatformWebViewFeature.
createPlatformWebViewFeatureStatic() → PlatformWebViewFeature
Creates a new empty PlatformWebViewFeature to access static methods.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance ↔ InAppWebViewPlatform?
The instance of InAppWebViewPlatform to use.
getter/setter pair