PDFConfiguration class

Class that represents the configuration data to use when generating a PDF representation of a web view's contents.

Constructors

PDFConfiguration({InAppWebViewRect? rect, PrintJobSettings? settings})

Properties

hashCode → int
The hash code for this object.
no setterinherited
rect ↔ InAppWebViewRect?
The portion of your web view to capture, specified as a rectangle in the view's coordinate system. The default value of this property is null, which captures everything in the view's bounds rectangle. If you specify a custom rectangle, it must lie within the bounds rectangle of the WebView object.
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings ↔ PrintJobSettings?
The print settings to use when generating the PDF. These settings control page size, orientation, margins, and other printing options. If not specified, default print settings will be used.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap({EnumMethod? enumMethod}) → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map, {EnumMethod? enumMethod}) → PDFConfiguration?
Gets a possible PDFConfiguration instance from a Map value.