onRefresh property

  1. @SupportedPlatforms.new(platforms: [AndroidPlatform(), IOSPlatform()])
void Function()? onRefresh
final

Event called when a swipe gesture triggers a refresh.

Officially Supported Platforms/Implementations:

  • Android WebView
  • iOS WKWebView

Use the PlatformPullToRefreshControllerCreationParams.isPropertySupported method to check if this property is supported at runtime.

Implementation

@SupportedPlatforms(platforms: [AndroidPlatform(), IOSPlatform()])
final void Function()? onRefresh;