PlatformStorageCreationParams class

Object specifying creation parameters for creating a PlatformStorage.

Platform specific implementations can add additional fields by extending this class. Object specifying creation parameters for creating a PlatformStorage.

Platform specific implementations can add additional fields by extending this class.

Annotations
  • @SupportedPlatforms.new(platforms: [AndroidPlatform(), IOSPlatform(), MacOSPlatform(), WebPlatform(), WindowsPlatform(), LinuxPlatform()])
  • @immutable

Constructors

PlatformStorageCreationParams({required PlatformInAppWebViewController? controller, required WebStorageType webStorageType})
Used by the platform implementation to create a new PlatformStorage.
const

Properties

controller → PlatformInAppWebViewController?
Controller used to interact with storage.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
webStorageType → WebStorageType
The web storage type: window.sessionStorage or window.localStorage.
final

Methods

isClassSupported({TargetPlatform? platform}) → bool
Check if the current class is supported by the defaultTargetPlatform or a specific platform.
isPropertySupported(PlatformStorageCreationParamsProperty property, {TargetPlatform? platform}) → bool
Check if the given property is supported by the defaultTargetPlatform or a specific platform.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited