ScrollViewDecelerationRate class

Class that represents a floating-point value that determines the rate of deceleration after the user lifts their finger.

Properties

hashCode → int
The hash code for this object.
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSupported() → bool
Checks if the value is supported by the defaultTargetPlatform.
name() → String
Gets the name of the value.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toNativeValue() → String?
Gets String native value if supported by the current platform, otherwise null.
toString() → String
A string representation of this object.
override
toValue() → String
Gets String value.

Operators

operator ==(Object value) → bool
The equality operator.
override

Static Properties

values → Set<ScrollViewDecelerationRate>
Set of all values of ScrollViewDecelerationRate.
final

Static Methods

asNameMap() → Map<String, ScrollViewDecelerationRate>
Creates a map from the names of ScrollViewDecelerationRate values to the values.
byName(String? name) → ScrollViewDecelerationRate?
Gets a possible ScrollViewDecelerationRate instance value with name name.
fromNativeValue(String? value) → ScrollViewDecelerationRate?
Gets a possible ScrollViewDecelerationRate instance from a native value.
fromValue(String? value) → ScrollViewDecelerationRate?
Gets a possible ScrollViewDecelerationRate instance from String value.

Constants

FAST → const ScrollViewDecelerationRate
A fast deceleration rate for a scroll view: 0.99.
NORMAL → const ScrollViewDecelerationRate
The default deceleration rate for a scroll view: 0.998.