TracingSettings class

Class that represents the settings used to configure the PlatformTracingController.

Officially Supported Platforms/Implementations:

Constructors

TracingSettings({List categories = const [], TracingMode? tracingMode})
Officially Supported Platforms/Implementations:

Properties

categories ↔ List
Adds predefined TracingCategory and/or custom String sets of categories to be included in the trace output.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tracingMode ↔ TracingMode?
The tracing mode for this configuration. When tracingMode is not set explicitly, the default is TracingMode.RECORD_CONTINUOUSLY.
getter/setter pair

Methods

copy() → TracingSettings
Returns a copy of TracingSettings.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts instance to a map.
toMap({EnumMethod? enumMethod}) → Map<String, dynamic>
Converts instance to a map.
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

fromMap(Map<String, dynamic>? map, {EnumMethod? enumMethod}) → TracingSettings?
Gets a possible TracingSettings instance from a Map value.
isClassSupported({TargetPlatform? platform}) → bool
Check if the current class is supported by the defaultTargetPlatform or a specific platform.
isPropertySupported(TracingSettingsProperty property, {TargetPlatform? platform}) → bool
Check if the current class is supported by the defaultTargetPlatform or a specific platform.